@@ -1,6 +1,6 @@
 package Example::Construction::Acme::Counter_v2;
 
-use Mic::Implementation
+use Mic::Impl
     has  => {
         COUNT => { },
     }, 
@@ -9,13 +9,13 @@ use Mic::Implementation
 sub BUILD {
     my ($self, $arg) = @_;
 
-    $self->{$COUNT} = $arg->{start};
+    $self->[COUNT] = $arg->{start};
 }
 
 sub next {
     my ($self) = @_;
 
-    $self->{$COUNT}++;
+    $self->[COUNT]++;
 }
 
 1;
