@@ -1,19 +1,19 @@
 package Example::Synopsis::ArraySet;
 
-use Mic::Implementation
+use Mic::Impl
     has => { SET => { default => sub { [] } } },
 ;
 
 sub has {
     my ($self, $e) = @_;
-    scalar grep { $_ == $e } @{ $self->{$SET} };
+    scalar grep { $_ == $e } @{ $self->[SET] };
 }
 
 sub add {
     my ($self, $e) = @_;
 
     if ( ! $self->has($e) ) {
-        push @{ $self->{$SET} }, $e;
+        push @{ $self->[SET] }, $e;
     }
 }
 
